@@ -19,12 +19,11 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
 
 #include "encodervorbis.h"
 #include "audiocd_vorbis_encoder.h"
-#include "encodervorbisconfig.h"
 
 #ifdef HAVE_VORBIS
 
@@ -33,14 +32,17 @@
 #include <stdlib.h>
 #include <kconfig.h>
 #include <knuminput.h>
-#include <qgroupbox.h>
-
+#include <q3groupbox.h>
+//Added by qt3to4:
+#include <Q3ValueList>
+#include <QByteArray>
+#include <QDateTime>
 #include <kglobal.h>  
 #include <klocale.h>
 
 extern "C"
 {
-  KDE_EXPORT void create_audiocd_encoders(KIO::SlaveBase *slave, QPtrList<AudioCDEncoder> &encoders)
+  KDE_EXPORT void create_audiocd_encoders(KIO::SlaveBase *slave, QList<AudioCDEncoder*> &encoders)
   {
     encoders.append(new EncoderVorbis(slave));
   }
@@ -81,7 +83,7 @@ EncoderVorbis::~EncoderVorbis(){
 
 QWidget* EncoderVorbis::getConfigureWidget(KConfigSkeleton** manager) const {
   (*manager) = Settings::self();
-  KGlobal::locale()->insertCatalogue("audiocd_encoder_vorbis");
+  KGlobal::locale()->insertCatalog("audiocd_encoder_vorbis");
   EncoderVorbisConfig *config = new EncoderVorbisConfig();
   config->kcfg_vorbis_quality->setRange(0.0, 10.0, 0.2, true);
   config->vorbis_bitrate_settings->hide();
@@ -178,13 +180,13 @@ long EncoderVorbis::flush_vorbis(void) {
         if (d->og.header_len) {
           output.setRawData(oggheader, d->og.header_len);
           ioslave->data(output);
-          output.resetRawData(oggheader, d->og.header_len);
+          output.clear();
         }
 
         if (d->og.body_len) {
           output.setRawData(oggbody, d->og.body_len);
           ioslave->data(output);
-          output.resetRawData(oggbody, d->og.body_len);
+          output.clear();
         }
         processed +=  d->og.header_len + d->og.body_len;
       }
@@ -226,7 +228,7 @@ unsigned long EncoderVorbis::size(long time_secs) const {
 }
 
 const char * EncoderVorbis::mimeType() const{
-  return "audio/vorbis";
+  return "audio/x-vorbis+ogg";
 }
 
 long EncoderVorbis::readInit(long /*size*/){
@@ -258,13 +260,13 @@ long EncoderVorbis::readInit(long /*size*/){
     if (d->og.header_len) {
       output.setRawData(oggheader, d->og.header_len);
       ioslave->data(output);
-      output.resetRawData(oggheader, d->og.header_len);
+      output.clear();
     }
 
     if (d->og.body_len) {
       output.setRawData(oggbody, d->og.body_len);
       ioslave->data(output);
-      output.resetRawData(oggbody, d->og.body_len);
+      output.clear();
     }
   }
   return 0;
@@ -301,28 +303,28 @@ void EncoderVorbis::fillSongInfo( KCDDB::CDInfo info, int track, const QString &
   if( !d->write_vorbis_comments )
     return;
 
-  typedef QPair<QCString, QVariant> CommentField;
-  QValueList<CommentField> commentFields;
+  typedef QPair<QByteArray, QVariant> CommentField;
+  Q3ValueList<CommentField> commentFields;
 
-  commentFields.append(CommentField("title", info.trackInfoList[track].get("title")));
-  commentFields.append(CommentField("artist", info.get("artist")));
-  commentFields.append(CommentField("album", info.get("title")));
-  commentFields.append(CommentField("genre", info.get("genre")));
-  commentFields.append(CommentField("tracknumber", QString::number(track+1)));
+  commentFields.append(CommentField("title", info.track(track).get(Title)));
+  commentFields.append(CommentField("artist", info.track(track).get(Artist)));
+  commentFields.append(CommentField("album", info.get(Title)));
+  commentFields.append(CommentField("genre", info.get(Genre)));
+  commentFields.append(CommentField("tracknumber", QString::number(track)));
   commentFields.append(CommentField("comment", comment));
 	
-  if (info.get("year").toInt() > 0) {
-    QDateTime dt(QDate(info.get("year").toInt(), 1, 1));
-    commentFields.append(CommentField("date", dt.toString(Qt::ISODate).utf8().data()));
+  if (info.get(Year).toInt() > 0) {
+    QDateTime dt( QDate(info.get(Year).toInt(), 1, 1) );
+    commentFields.append(CommentField("date", dt.toString(Qt::ISODate).toUtf8().data()));
   }
 
-  for(QValueListIterator<CommentField> it = commentFields.begin(); it != commentFields.end(); ++it) {
+  for(Q3ValueListIterator<CommentField> it = commentFields.begin(); it != commentFields.end(); ++it) {
 
     // if the value is not empty
     if(!(*it).second.toString().isEmpty()) {
 
       char *key = qstrdup((*it).first);
-      char *value = qstrdup((*it).second.toString().utf8().data());
+      char *value = qstrdup((*it).second.toString().toUtf8().data());
 
       vorbis_comment_add_tag(&d->vc, key, value);
 
